/********************************************************************
*==================  		ЗАО "ННН"		========================*
*********************************************************************/
/*!
* \file				ystddelegate.cpp
* \brief			Реализация класса YStdDelegate
* \framework{		Qt 4.3.4}
* \compiller{		GCC (MinGW32-gcc rev3.4.5)}
* \date				6.04.2008	8.04.2008
* \author			Литкевич Юрий Иванович
*/
/*
* Support E-mail:	lit-uriy@yandex.ru
* Лицензия:			GNU GPLv2
* TabSize:			4
* Encodding:		UTF-8 (w/o BOM)	
*						 
* 							
* 		 					
* 							
* Log:
* Date				Athor				Description
* 
*
********************************************************************/



#include <QtGui>
#include <QtDebug>

#include "ystddelegate.h"

/*!
 *	\brief	Конструктор класса
 *
 *	Создает делегат с заданным типом виджета-редактора
 */
YStdDelegate::YStdDelegate(TypeEditor type, QObject *parent)
    : QItemDelegate(parent)
{
	qDebug() << "YStdDelegate::YStdDelegate";
	typeeditor = type;
}


/*!
 *	\brief	Функция создания виджета-редактора
 */
QWidget *YStdDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem &,
									const QModelIndex &) const
{
	qDebug() << "YStdDelegate::createEditor";

  QWidget *editor;

	switch(typeeditor)
	{
		case TBool:
		{
			QComboBox *cmbox = new QComboBox(parent);
			cmbox->setObjectName("QComboBox");
			cmbox->addItem("0");
			cmbox->addItem("1");
			editor = static_cast<QWidget *>(cmbox);
			break;
	    }
		case TQDateTimeEdit:
		{
			editor = static_cast<QDateTimeEdit *>(new QDateTimeEdit(parent));
			editor->setObjectName("QDateTimeEdit");
			break;
		}
		default:
		{
			editor = static_cast<QSpinBox *>(new QSpinBox(parent));
			editor->setObjectName("default");

		}
	}
	connect(editor, SIGNAL(destroyed(QObject *)),
			this, SLOT(destroyEditor(QObject *)));
	qDebug() << "createEditor:" << editor;
	return editor;
}

/*!
 *	\brief	Функция заполнения виджета-редактора данными из модели
 */
void YStdDelegate::setEditorData(QWidget *editor, const QModelIndex &index) const
{
qDebug() << "YStdDelegate::setEditorData";

    QVariant data = index.model()->data(index, Qt::DisplayRole);

	switch(typeeditor)
	{
		case TBool:
			QComboBox *cmbox = static_cast<QComboBox *>(editor);
			if (data.toInt())
			{
				cmbox->setCurrentIndex(cmbox->findText("1"));
			}   
			else
			{
				cmbox->setCurrentIndex(cmbox->findText("0"));			
			}
			break;
		case TQDateTimeEdit:
			QDateTimeEdit *dtedit = static_cast<QDateTimeEdit *>(editor);
			
			dtedit->setDateTime(data.toDateTime());
			break;
		default:
			QSpinBox *spinBox = static_cast<QSpinBox *>(editor);
			spinBox->setValue(data.toInt());
	}
    
   
}

/*!
 *	\brief	Функция заполнения модели данными из виджета-редактора
 */
void YStdDelegate::setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const
{
qDebug() << "YStdDelegate::setModelData";
  
  QVariant data/*, newdata*/;

	switch(typeeditor)
	{
		case TBool:
		{
			QComboBox *cmbox = static_cast<QComboBox *>(editor);
			data = cmbox->currentText();
			//newdata
			/*
			qDebug() << "Index: " << index;
			qDebug() << "Index.Model: " <<  index.model();
			qDebug() << "Model: " <<  index.model();
			qDebug() << "------------------";*/
			break;
		}
		case TQDateTimeEdit:
		{
			QDateTimeEdit *dtedit = static_cast<QDateTimeEdit *>(editor);
			data = dtedit->dateTime();
			break;
		}
		default:
		{
			QSpinBox *spinBox = static_cast<QSpinBox *>(editor);
			spinBox->interpretText();
			data = spinBox->value();
		}
	}

    model->setData(index, data, Qt::EditRole);
}

void YStdDelegate::updateEditorGeometry(QWidget *editor,
    const QStyleOptionViewItem &option, const QModelIndex &/* index */) const
{
qDebug() << "YStdDelegate::updateEditorGeometry";
    editor->setGeometry(option.rect);
}

void YStdDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option,
                                const QModelIndex &index) const
{
qDebug() << "YStdDelegate::paint";
	QItemDelegate::paint(painter, option, index);

}



void YStdDelegate::destroyEditor(QObject *obj)
{

	qDebug() << "destroyEditor:" << obj;

}


