/********************************************************************
*==================  		ЗАО "ННН"		========================*
*********************************************************************/
/*!
* \file				ystddelegate.h
* \brief			Интерфейс класса YStdDelegate
* \framework{		Qt 4.3.4}
* \compiller{		GCC (MinGW32-gcc rev3.4.5)}
* \date				6.04.2008	8.04.2008
* \author			Литкевич Юрий Иванович
*
* Класс построен на основе примера Spin Box Delegate, в ходящий
* в комплект библиотек Qt 4.3.4 (Trolltech ASA (c) 2007)
*/
/*
* Support E-mail:	lit-uriy@yandex.ru
* Лицензия:			GNU GPLv2
* TabSize:			4
* Encodding:		UTF-8 (w/o BOM)	
*						 
* 							
* 		 					
* 							
* Log:
* Date				Athor				Description
* 
*
********************************************************************/
#ifndef YSTDDELEGATE_H
#define YSTDDELEGATE_H

#include <QItemDelegate>
#include <QModelIndex>
#include <QObject>
#include <QSize>
#include <QSpinBox>


/*!
 *	\class	YStdDelegate
 *	\brief	Класс стандартных делегатов
 *
 *	Создает делегат с виджетом-редактором из числа
 *	широко распространенных типов (QSpinBox, QComboBox, QDateTimeEdit)
 */
class YStdDelegate : public QItemDelegate
{
    Q_OBJECT

public:
   /*!
	*	\brief	Определение типов виджетов-редакторов
	*/
	enum TypeEditor
	{
		TQSpinBox,	//!< -- делегат на основе QSpinBox
		TBool,		//!< -- делегат на основе QComboBox, оперирующий 2 значениями ,"1" и "0"
		TQDateTimeEdit//!< -- делегат на основе QDateTimeEdit
	};
	
   /*!
	*	\brief	Конструктор класса
	*	\param	type - тип виджета-редактора (TypeEditor)
	*	\param	parent - указатель на родительский виджет
	*	Создает делегат с заданным типом виджета-редактора
	*/
    YStdDelegate(TypeEditor type, QObject *parent = 0);
	
   /*!
	*	\brief	Функция создания виджета-редактора
	*/
    QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option,
                          const QModelIndex &index) const;
   /*!
	*	\brief	Функция заполнения виджета-редактора данными из модели
	*/	
    void setEditorData(QWidget *editor, const QModelIndex &index) const;
   /*!
	*	\brief	Функция заполнения модели данными из виджета-редактора
	*/
    void setModelData(QWidget *editor, QAbstractItemModel *model,
                      const QModelIndex &index) const;

    void updateEditorGeometry(QWidget *editor,
        const QStyleOptionViewItem &option, const QModelIndex &index) const;
	
	void paint(QPainter *painter, const QStyleOptionViewItem &option,
               const QModelIndex &index) const;

private:
	int typeeditor;

private slots:
	void destroyEditor(QObject *obj);
};

#endif //YSTDDELEGATE_H
